<?php
	session_start();
	if (!isset($_SESSION['view_id']))
		header("Location: index.php");

	$user_name = $_POST['user_name'];
	$password = $_POST['password'];
	$view_id = $_POST['selectAccessLevel'];

	include "../connect/db_connect.php";
	
	//First check to see if user exists.
	$query = "SELECT * FROM users WHERE `UserID` = '$user_name'";
	$result = $zen_dbh->query($query);
	$row = $result->fetch(PDO::FETCH_ASSOC);
	$tmp_user_name = $row["UserID"];
	if ($tmp_user_name)
	{
		echo "$user_name already exists in database.  Click <a href=\"users.php\" title=\"here\">here</a> to enter a different user name.";
		exit;
	}
	// Add user to database.
	//$query = "INSERT INTO users SET UserID='$user_name', Password='$password', view_id='$view_id'";
	if ($view_id == 1)
		$access_level = "admin";
	elseif ($view_id == 2)
		$access_level = "user";
	elseif ($view_id == 3)
		$access_level = "reseller";
	$query = "INSERT INTO users SET UserID='$user_name', Password='$password', AccessLevel='$access_level'";
	$cnt = $zen_dbh->exec($query);
	
	header("Location: users.php");
	
?>
